"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const VDocument_1 = require("../core/VDocument");
const VPage_1 = require("../core/VPage");
const utils_1 = require("./utils");
let vDocument;
let vBrowser;
let page;
beforeAll(async () => {
    vBrowser = await utils_1.launch();
    page = (await vBrowser.newPage()).frame;
});
afterAll(async () => {
    await vBrowser.close();
});
beforeEach(async () => {
    await page.goto(utils_1.servedFileURL('page.html'));
    vDocument = await VDocument_1.VDocument.create(new VPage_1.VPage(page), () => document);
});
test('#getSheetDataList()', async () => {
    const result = await vDocument.getSheetDataList();
    expect(result).toEqual([
        { type: 'link', link: utils_1.servedFileURL('main.css') },
        { type: 'text', text: expect.stringMatching(/\.style-tag/) },
    ]);
});
test('#setUuidToIFrames()', async () => {
    await vDocument.setUuidToIFrames();
    const uuids = await page.$$eval('iframe', els => els.map(el => el.dataset.vanillaClipperIframeUuid));
    expect(uuids).toHaveLength(1);
    expect(uuids[0]).toHaveLength(36);
});
//# sourceMappingURL=VDocument.test.js.map