"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const element_1 = require("../utils/element");
const utils_1 = require("./utils");
let vBrowser;
let metadata;
let html;
let savedPage;
let childFrame;
beforeAll(async () => {
    vBrowser = await utils_1.launch();
    const vPage = await vBrowser.newPage({ url: utils_1.servedFileURL('page.html') });
    const clipped = await vPage.clip();
    await vPage.close();
    metadata = clipped.metadata;
    html = clipped.html;
});
beforeEach(async () => {
    savedPage = (await vBrowser.newPage()).frame;
    await savedPage.setContent(html);
    childFrame = savedPage.frames()[1];
});
afterEach(async () => {
    await savedPage.close();
});
afterAll(async (done) => {
    await vBrowser.close();
    done();
});
test('metadata', async () => {
    expect(metadata).toMatchObject({
        _version: 1,
        domain: 'localhost',
        hostname: 'localhost',
        url: utils_1.servedFileURL('page'),
        title: 'Vanilla Test',
    });
});
test('element count', async () => {
    await expect(savedPage.$$(`link[rel=stylesheet], [src]:not(${element_1.getVAttrSelector.src()}):not(a)`)).resolves.toHaveLength(0);
    await expect(savedPage.$$(`head style${element_1.getVAttrSelector.style()}`)).resolves.toHaveLength(2);
    await expect(savedPage.$$(`head script${element_1.getVAttrSelector.script()}`)).resolves.toHaveLength(1);
    await expect(savedPage.$$(`body img${element_1.getVAttrSelector.src(utils_1.servedFileURL('icon.png'))}`)).resolves.toHaveLength(1);
});
test('style[data-vanilla-clipper-style] content', async () => {
    const texts = await savedPage.$$eval(`head style${element_1.getVAttrSelector.style()}`, els => els.map(el => el.innerHTML));
    expect(texts).toEqual([
        expect.stringContaining('.external'),
        expect.stringContaining('.style-tag'),
    ]);
});
test('set [src] attribute from dataMap', async () => {
    const src = await savedPage.$eval(`img${element_1.getVAttrSelector.src()}`, img => img.getAttribute('src'));
    const iconBuffer = await fs_extra_1.readFile(utils_1.publicFilePath('icon.png'));
    expect(src).toBe('data:image/png;base64,' + iconBuffer.toString('base64'));
});
test('iframe - element count', async () => {
    await expect(childFrame.$$(`link[rel=stylesheet], [src]:not(${element_1.getVAttrSelector.src()}):not(a)`)).resolves.toHaveLength(0);
    await expect(childFrame.$$(`head style${element_1.getVAttrSelector.style()}`)).resolves.toHaveLength(2);
    await expect(childFrame.$$(`head script${element_1.getVAttrSelector.script()}`)).resolves.toHaveLength(1);
    await expect(childFrame.$$(`body img${element_1.getVAttrSelector.src(utils_1.servedFileURL('icon.png'))}`)).resolves.toHaveLength(1);
});
//# sourceMappingURL=VPage.test.js.map