"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const css_tree_1 = __importDefault(require("css-tree"));
const css_1 = require("../utils/css");
const utils_1 = require("./utils");
describe('optimizeCSS()', () => {
    test('extract woff2 and local', () => {
        const fontURL = utils_1.servedFileURL('fonts/awesome.woff2');
        expect(css_1.optimizeCSS(`@font-face {
                    font-family: 'Awesome Font';
                    src: url('/fonts/awesome.woff') format('woff');
                    src:
                        url('/fonts/awesome.otf') format('opentype'),
                        local('Awesome Font'),
                        url('/fonts/awesome.woff2') format('woff2'),
                        url('/fonts/awesome.eot') format('embedded-opentype');
                }`, utils_1.servedFileURL(''))).toEqual({
            text: css_tree_1.default.generate(css_tree_1.default.parse(`@font-face {
                    src:
                        local('Awesome Font'),
                        url(${fontURL}) format('woff2');
                    font-family: 'Awesome Font';
                }`)),
            urls: new Set([fontURL]),
        });
    });
    test('extract woff - without quotes and format name', () => {
        const fontURL = utils_1.servedFileURL('fonts/awesome.woff');
        expect(css_1.optimizeCSS(`@font-face {
                    font-family: 'Awesome Font';
                    src:
                        url('/fonts/awesome.otf') format('opentype'),
                        url(/fonts/awesome.woff),
                        url('/fonts/awesome.eot') format('embedded-opentype');
                }`, utils_1.servedFileURL(''))).toEqual({
            text: css_tree_1.default.generate(css_tree_1.default.parse(`@font-face {
                    src: url(${utils_1.servedFileURL('fonts/awesome.woff')}) format('woff');
                    font-family: 'Awesome Font';
                }`)),
            urls: new Set([fontURL]),
        });
    });
});
//# sourceMappingURL=utils.css.test.js.map