"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const clean_css_1 = __importDefault(require("clean-css"));
const fs_extra_1 = require("fs-extra");
const data_1 = require("../utils/data");
const utils_1 = require("./utils");
const cleanCSS = new clean_css_1.default();
const minify = (text) => cleanCSS.minify(text).styles;
const iconURL = utils_1.servedFileURL('icon.png');
const cssURL = utils_1.servedFileURL('main.css');
const iconBuffer = fs_extra_1.readFileSync(utils_1.publicFilePath('icon.png'));
const iconDataURL = `data:image/png;base64,${iconBuffer.toString('base64')}`;
const cssFileText = fs_extra_1.readFileSync(utils_1.publicFilePath('main.css'), 'utf8');
test('extractOrFetchCSSText()', async () => {
    const text = '.text { opacity: 1; }';
    const { texts, urls } = await data_1.extractOrFetchCSS([{ type: 'text', text }, { type: 'link', link: cssURL }], utils_1.servedFileURL(''));
    expect(texts).toEqual([minify(text), minify(cssFileText).replace('/icon.png', iconURL)]);
    expect(urls).toEqual(new Set([iconURL]));
});
test('dataSourceUrlsToDataList', async () => {
    const dataList = await data_1.dataSourceURLsToDataList([new Set([iconURL])], utils_1.servedFileURL('page'));
    expect(dataList).toEqual([[iconURL, iconDataURL]]);
});
test('dataListToScriptString', () => {
    const script = data_1.dataListToScriptString([[iconURL, iconDataURL]], [cssFileText]);
    expect(script).toMatch(`const dataMap = new Map([["${iconURL}","${iconDataURL}"]])`);
    expect(script).toMatch(`const styleElements = [${JSON.stringify(cssFileText)}]`);
});
//# sourceMappingURL=utils.data.test.js.map