#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const luxon_1 = require("luxon");
const path_1 = require("path");
const yargs_1 = __importDefault(require("yargs"));
const __1 = require("..");
const utils_1 = require("../utils");
exports.clip = async () => {
    const { _: urls, noSandbox, language, directory, accountLabel, userDataDir, headless, selector, emulate: deviceName, } = yargs_1.default
        .option('no-sandbox', {
        alias: 'n',
        boolean: true,
        desc: 'Launch Puppeteer with "--no-sandbox --disable-setuid-sandbox" args',
    })
        .option('headless', {
        alias: 'h',
        boolean: true,
        default: true,
        desc: 'Headless mode',
    })
        .option('language', {
        alias: 'l',
        string: true,
        desc: 'Browser language',
    })
        .option('directory', {
        alias: 'd',
        string: true,
        default: '.',
        desc: 'Output directory',
    })
        .option('account-label', {
        alias: 'a',
        string: true,
        default: 'default',
        desc: 'Account label',
    })
        .option('emulate', {
        alias: 'e',
        string: true,
        desc: 'Emulate a device (Defined in `puppeteer-core/DeviceDescriptors`)',
    })
        .option('selector', {
        alias: 's',
        string: true,
        desc: 'Selector for a HTML element to extract (It may break the layout)',
    })
        .option('user-data-dir', {
        alias: 'u',
        string: true,
        desc: 'Path to a User Data Directory',
    })
        .demandCommand(1).argv;
    try {
        const dateString = luxon_1.DateTime.local().toFormat('yyyyMMdd');
        const device = __1.devices[deviceName];
        const vBrowser = await __1.VBrowser.launch(noSandbox, { userDataDir, headless }, language);
        const vPage = await vBrowser.newPage({ device });
        const successCount = await urls.reduce(async (prevPromise, url, i) => {
            const _successCount = await prevPromise;
            const outputPath = path_1.join(directory, `${dateString}-${__1.filenamifyUrl(url)}.html`);
            utils_1.sig.pending('[%d/%d] Cilpping %s', i + 1, urls.length, url);
            try {
                await vPage.login(url, accountLabel);
                await vPage.goto(url);
                const { html } = await vPage.clip({ selector });
                await fs_extra_1.outputFile(outputPath, html);
                utils_1.sig.success('Saved as %s', outputPath);
                return _successCount + 1;
            }
            catch (error) {
                utils_1.sig.error(error);
                return _successCount;
            }
        }, Promise.resolve(0));
        await vPage.close();
        if (successCount)
            utils_1.sig.complete('Clipped %d page%s', successCount, successCount === 1 ? '' : 's');
        await vBrowser.close();
    }
    catch (error) {
        utils_1.sig.error(error);
    }
    finally {
        process.exit(0);
    }
};
exports.clip();
//# sourceMappingURL=clip.js.map