"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class VDocument {
    constructor(vFrame, documentHandle) {
        this.vFrame = vFrame;
        this.documentHandle = documentHandle;
    }
    static async create(vFrame, fn) {
        const handle = await vFrame.frame.evaluateHandle(fn);
        return new VDocument(vFrame, handle.asElement());
    }
    async eval(fn, ...args) {
        const result = await this.vFrame.frame.evaluate(fn, this.documentHandle, ...args);
        return result;
    }
    async $(selector) {
        const result = await this.documentHandle.$(selector);
        return result;
    }
    async $$(selector) {
        const result = await this.documentHandle.$$(selector);
        return result;
    }
    getSheetDataList() {
        return this.eval(document => {
            const sheets = [...document.styleSheets]
                .filter((s) => s instanceof CSSStyleSheet)
                .filter(s => !s.disabled);
            return sheets.map(s => {
                if (s.href) {
                    return { type: 'link', link: s.href };
                }
                else {
                    try {
                        return {
                            type: 'text',
                            text: [...s.cssRules].map(rule => rule.cssText).join('\n'),
                        };
                    }
                    catch (error) {
                        return { type: 'error', error: error };
                    }
                }
            });
        });
    }
    setUuidToIFrames() {
        this.eval(document => {
            function uuidv4() {
                return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
                    var r = (Math.random() * 16) | 0, v = c == 'x' ? r : (r & 0x3) | 0x8;
                    return v.toString(16);
                });
            }
            document.querySelectorAll('iframe').forEach(el => {
                el.dataset.vanillaClipperIframeUuid = uuidv4();
            });
        });
    }
}
exports.VDocument = VDocument;
//# sourceMappingURL=VDocument.js.map