"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const jsdom_1 = require("jsdom");
const tldjs_1 = require("tldjs");
const plugins_1 = require("../plugins");
const data_1 = require("../utils/data");
const document_1 = require("../utils/document");
const element_1 = require("../utils/element");
const html_1 = require("../utils/html");
const VDocument_1 = require("./VDocument");
const VMetadata_1 = require("./VMetadata");
class VFrame {
    constructor(frame) {
        this.frame = frame;
        this.isRoot = false;
    }
    async clip({ minify = true, selector = undefined } = {}) {
        const originalDocument = await VDocument_1.VDocument.create(this, () => document);
        await originalDocument.setUuidToIFrames();
        const { doctype, html: originalHTML, title, location } = await originalDocument.eval(d => ({
            doctype: d.doctype ? new XMLSerializer().serializeToString(d.doctype) : undefined,
            html: d.documentElement.outerHTML,
            title: d.title,
            location: d.location,
        }));
        const sheetDataList = await originalDocument.getSheetDataList();
        const { window } = new jsdom_1.JSDOM(originalHTML, { url: location.href });
        const finder = element_1.createElementFinder(window.document);
        if (selector) {
            const el = window.document.body.querySelector(selector);
            if (el)
                window.document.body.innerHTML = el.outerHTML;
        }
        plugins_1.jsdomPlugins.exec(window.document);
        await Promise.all([
            (async () => {
                const iframes = finder(element_1.getVAttrSelector.iframeUuid());
                const iframeUuidsToClip = iframes.map(el => el.dataset.vanillaClipperIframeUuid);
                const iframeDataList = await rain_1.Rarray.waitAll(iframeUuidsToClip, async (uuid) => {
                    try {
                        const handle = await originalDocument.$(element_1.getVAttrSelector.iframeUuid(uuid));
                        const frame = await handle.contentFrame();
                        const vFrame = new VFrame(frame);
                        const { html } = await vFrame.clip();
                        return { uuid, html };
                    }
                    catch (error) {
                        return { uuid, html: '' };
                    }
                });
                document_1.embedIFrameContents(finder, iframeDataList);
            })(),
            (async () => {
                const urlsInAttrs = document_1.moveAttrToDatasetAndReturnURLs(finder);
                const sheets = await data_1.extractOrFetchCSS(sheetDataList, location.href);
                const dataList = await data_1.dataSourceURLsToDataList([sheets.urls, urlsInAttrs], location.href);
                const scriptString = data_1.dataListToScriptString(dataList, sheets.texts);
                document_1.appendScriptToHead(window.document, scriptString);
            })(),
        ]);
        let vMetadata;
        if (this.isRoot) {
            vMetadata = new VMetadata_1.VMetadata();
            vMetadata.set({
                domain: tldjs_1.getDomain(location.href) || location.hostname,
                hostname: location.hostname,
                url: location.href,
                title,
            });
            await vMetadata.validate();
        }
        return {
            html: html_1.generateFullHTML({
                doctype,
                html: window.document.documentElement.outerHTML,
                vMetadata,
                minify,
            }),
            metadata: vMetadata,
        };
    }
}
exports.VFrame = VFrame;
//# sourceMappingURL=VFrame.js.map