"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const url_1 = require("url");
const _1 = require(".");
const css_1 = require("./css");
const element_1 = require("./element");
exports.dataURLPattern = /^data:[\w\/\+]+(?:;.*)?,/;
async function extractOrFetchCSS(sheetDataList, currentURL) {
    const sheets = await rain_1.Rarray.waitAll(sheetDataList, async (data) => {
        try {
            if (data.type === 'error')
                throw data.error;
            if (data.type === 'text')
                return css_1.optimizeCSS(data.text, currentURL);
            const { body } = await _1.got.get(data.link);
            return css_1.optimizeCSS(body, data.link);
        }
        catch (_error) {
            return { text: _1.commentOutError(_error), urls: new Set() };
        }
    });
    return sheets.reduce(({ texts, urls }, sheet) => {
        return { texts: [...texts, sheet.text], urls: new Set([...urls, ...sheet.urls]) };
    }, { texts: [], urls: new Set() });
}
exports.extractOrFetchCSS = extractOrFetchCSS;
async function dataSourceURLsToDataList(dataSourceURLs, currentURL) {
    const urls = dataSourceURLs.reduce((prev, current) => [...prev, ...current], []);
    return rain_1.Rarray.waitAll(urls, async (url) => {
        const dataURL = await getDataURL(url, currentURL);
        return [url, dataURL];
    });
}
exports.dataSourceURLsToDataList = dataSourceURLsToDataList;
function dataListToScriptString(dataList, cssTexts) {
    return `{
        const dataMap = new Map(${JSON.stringify(dataList)})

        const styleElements = ${JSON.stringify(cssTexts)}
            .map(text =>
                text.replace(
                    ${css_1.cssURLPattern.toString()},
                    (_, prefix, url) => \`\${prefix}('\${dataMap.get(url)}')\`
                )
            )
            .map(text => {
                const el = document.createElement('style')
                el.dataset.vanillaClipperStyle = ''
                el.innerHTML = text
                return el
            })

        document.head.append(...styleElements)

        document.addEventListener('DOMContentLoaded', () => {
            const elements = document.querySelectorAll('${element_1.getVAttrSelector.src()}, ${element_1.getVAttrSelector.href()}')
            elements.forEach(el => {
                const { vanillaClipperSrc, vanillaClipperHref } = el.dataset
                const src = dataMap.get(vanillaClipperSrc)
                const href = dataMap.get(vanillaClipperHref)

                if (src) el.setAttribute('src', src)
                if (href) el.setAttribute('href', href)
            })
        })
    }`;
}
exports.dataListToScriptString = dataListToScriptString;
async function getDataURL(url, currentURL) {
    try {
        const { body, headers: { 'content-type': mimetype }, } = await _1.got.get(currentURL ? url_1.resolve(currentURL, url) : url, { encoding: null });
        return `data:${mimetype};base64,${body.toString('base64')}`;
    }
    catch (error) {
        return `data:text/css,${_1.commentOutError(error)}`;
    }
}
exports.getDataURL = getDataURL;
//# sourceMappingURL=data.js.map